E1 = None
E2 = None
E3 = None
F_ph_array = None
longitud_array = None
Sigma1_array = None
Sigma2_array = None
Sigma3_array = None
Fuente_Luz_array = None
pf1_v = None
pf2_v = None
pf3_v = None
n_1 = None
n_2 = None
n_3 = None
nc_ = None
nv_ = None
m_ = None

def set_values():
    global E1, E2, E3
    E1 = float(input("Ingrese E1: "))
    E2 = float(input("Ingrese E2: "))
    E3 = float(input("Ingrese E3: "))

def set_test_values(e1, e2, e3):
    global E1, E2, E3
    E1, E2, E3 = e1, e2, e3



from setuptools import setup, find_packages
import os

with open(os.path.join(os.path.dirname(__file__), 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='osl_analysis',
    version='0.1.18',
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    description='program for the analysis of physical processes of OSL curves',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='EDWIN JOEL PILCO QUISPE',
    author_email='edwinpilco10@gmail.com',
    url='https://pypi.org/project/OSL_ANALYSIS/',
    install_requires=[
        'numpy',
        'matplotlib',
        'scipy',
        'pandas',
        'prettytable',
        'ipython'
    ],
    python_requires='>=3.6',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering',
    ],
)